@@ -1,11 +1,29 @@
-import datetime
-from scrapy import log
+#Stage 2 Update (Python 3)
+from __future__ import unicode_literals
+from builtins import str
+import datetime, logging, re
+
+
+def join(input_list, loader_context):
+    if not isinstance(input_list, list):
+        input_list = list(input_list)
+    separator = loader_context.get('join', ' ')
+    return separator.join(input_list)
 
 
 def string_strip(text, loader_context):
+    if not isinstance(text, str):
+        text = str(text)
     chars = loader_context.get('string_strip', ' \n\t\r')
     return text.strip(chars)
+
+
+def remove_chars(text, loader_context):
+    pattern = loader_context.get('remove_chars', '')
+    result_str = re.sub(pattern, '', str(text))
     
+    return result_str
+
 
 def pre_string(text, loader_context):
     pre_str = loader_context.get('pre_string', '')
@@ -36,6 +54,20 @@ def replace(text, loader_context):
     return replace
 
 
+def substr_replace(text, loader_context):
+    substr_replace = loader_context.get('substr_replace', '')
+    try:
+        pos = re.search('[^\\\]:', substr_replace).start()
+        orig_string = substr_replace[0:pos+1]
+        new_string = substr_replace[pos+2:]
+        orig_string = orig_string.replace('\:', ':')
+        new_string = new_string.replace('\:', ':')
+    except AttributeError:
+        loader_context.get('spider').log('Context for substr_replace processor has wrong format ("{t}", Format string: "{f}")!'.format(t=text, f=cformat), logging.ERROR)
+        return None
+    return text.replace(orig_string, new_string)
+
+
 def static(text, loader_context):
     static = loader_context.get('static', '')
     return static
@@ -53,7 +85,7 @@ def date(text, loader_context):
         else:
             date = datetime.datetime.strptime(text, cformat)
     except ValueError:
-        loader_context.get('spider').log('Date could not be parsed ("%s", Format string: "%s")!' % (text, cformat), log.ERROR)
+        loader_context.get('spider').log('Date could not be parsed ("{t}", Format string: "{f}")!'.format(t=text, f=cformat), logging.ERROR)
         return None
     return date.strftime('%Y-%m-%d')
 
@@ -63,11 +95,29 @@ def time(text, loader_context):
     try:
         time = datetime.datetime.strptime(text, cformat)
     except ValueError:
-        loader_context.get('spider').log('Time could not be parsed ("%s", Format string: "%s")!' % (text, cformat), log.ERROR)
+        loader_context.get('spider').log('Time could not be parsed ("{t}", Format string: "{f}")!'.format(t=text, f=cformat), logging.ERROR)
         return None
     return time.strftime('%H:%M:%S')
 
 
+def ts_to_date(ts_str, loader_context):
+    try:
+        ts_int = int(ts_str)
+        return datetime.datetime.fromtimestamp(ts_int).strftime('%Y-%m-%d')
+    except ValueError:
+        loader_context.get('spider').log('Timestamp could not be parsed ("{ts}")!'.format(ts=ts_str), logging.ERROR)
+        return None
+
+
+def ts_to_time(ts_str, loader_context):
+    try:
+        ts_int = int(ts_str)
+        return datetime.datetime.fromtimestamp(ts_int).strftime('%H:%M:%S')
+    except ValueError:
+        loader_context.get('spider').log('Timestamp could not be parsed ("{ts}")!'.format(ts=ts_str), logging.ERROR)
+        return None
+
+
 def _breakdown_time_unit_overlap(time_str, limit):
     time_list = time_str.split(':')
     first = int(time_list[0])
@@ -104,7 +154,7 @@ def duration(text, loader_context):
     if(cformat == '%S'):
         if text_int:
             if text_int >= 3600:
-                hours_str = str(text_int / 3600) + ':'
+                hours_str = str(text_int // 3600) + ':'
                 secs_under_hour_str = str(text_int % 3600)
                 text = hours_str + _breakdown_time_unit_overlap(secs_under_hour_str, 60)
                 cformat = '%H:%M:%S'
@@ -114,6 +164,6 @@ def duration(text, loader_context):
     try:
         duration = datetime.datetime.strptime(text, cformat)
     except ValueError:
-        loader_context.get('spider').log('Duration could not be parsed ("%s", Format string: "%s")!' % (text, cformat), log.ERROR)
+        loader_context.get('spider').log('Duration could not be parsed ("{t}", Format string: "{f}")!'.format(t=text, f=cformat), logging.ERROR)
         return None
     return duration.strftime('%H:%M:%S')
