@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 from dynamic_scraper.spiders.django_checker import DjangoChecker
 from open_news.models import Article
 
@@ -9,6 +10,6 @@ class ArticleChecker(DjangoChecker):
     def __init__(self, *args, **kwargs):
         self._set_ref_object(Article, **kwargs)
         self.scraper = self.ref_object.news_website.scraper
-        self.scrape_url = self.ref_object.url
+        #self.scrape_url = self.ref_object.url
         self.scheduler_runtime = self.ref_object.checker_runtime
         super(ArticleChecker, self).__init__(self, *args, **kwargs)
\ No newline at end of file
